@@ -46,6 +46,11 @@ dReport <-
   what     <- match.arg(what)
   byx.type <- match.arg(byx.type)
   tvar     <- getgreportOption('tx.var')
+
+  if(grepl('[^a-zA-Z-]', panel))
+    stop('panel must contain only A-Z a-z -')
+  if(length(subpanel) && grepl('[^a-zA-Z-]', subpanel))
+    stop('subpanel must contain only A-Z a-z -')
   
   center <- 'centerline'
   legend <- NULL
@@ -248,6 +253,7 @@ dReport <-
                if(length(ylabs) < 7) past(ylabs) else
                paste(length(ylabs), 'variables'))
   al <- tolower(a)
+  al <- latexTranslate(al)
   
   if(!length(head))
     head <-
@@ -354,7 +360,7 @@ dReport <-
   if(substring(what, 1, 3) == 'byx')
     poptab <- latexit(s, what, byx.type, file=file)
   else if(what == 'proportions') {
-    z <- latex(s, groups=groups, size='small', file=file)
+    z <- latex(s, groups=groups, size='small', file=file, append=TRUE)
     poptab <- if(attr(z, 'ngrouplevels') > 3) 'full' else 'mini'
   }
   else if(what == 'box' || (what == 'xy' && length(fun))) {
@@ -382,7 +388,7 @@ dReport <-
   cap <- sprintf('%s~\\hfill\\%s', cap, lttpop)
 
   endPlot()
-    
+
   putFig(panel = panel, name = lb, caption = shortcap,
          longcaption = cap,  tcaption=tcap,
          tlongcaption = paste(tcap, legend, sep=''),
